@@ -1,9 +1,7 @@
 use strict;
 use warnings;
 package TestSchema::TestObjectExtra;
-our $VERSION = '0.003';
-
-use base 'DBIx::Class';
+use parent 'DBIx::Class';
 use Mixin::ExtraFields::Driver::DBIC -setup => { table => 'object_info' };
 
 __PACKAGE__->belongs_to(object => 'TestSchema::TestObject',
